==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/data/impl/src/main/java/org/apache/deltaspike/data/impl/handler/CdiQueryContextHolder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.impl.handler;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.inject.Produces;
import java.util.Stack;

@ApplicationScoped
public class CdiQueryContextHolder
{

    private final ThreadLocal<Stack<CdiQueryInvocationContext>> contextStack =
            new ThreadLocal<Stack<CdiQueryInvocationContext>>();

    public void set(CdiQueryInvocationContext context)
    {
        if (contextStack.get() == null)
        {
            contextStack.set(new Stack<CdiQueryInvocationContext>());
        }
        contextStack.get().push(context);
    }

    @Produces
    public CdiQueryInvocationContext get()
    {
        if (contextStack.get() != null && !contextStack.get().isEmpty())
        {
            return contextStack.get().peek();
        }
        return null;
    }

    public void dispose()
    {
        if (contextStack.get() != null && !contextStack.get().isEmpty())
        {
            CdiQueryInvocationContext ctx = contextStack.get().pop();
            ctx.cleanup();
        }
        if (contextStack.get() != null && contextStack.get().isEmpty())
        {
            contextStack.remove();
        }
    }

}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/data/impl/src/main/java/org/apache/deltaspike/data/impl/handler/CdiQueryContextHolder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.impl.handler;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.inject.Produces;
import java.util.Stack;

@ApplicationScoped
public class CdiQueryContextHolder
{

    private final ThreadLocal<Stack<CdiQueryInvocationContext>> contextStack =
            new ThreadLocal<Stack<CdiQueryInvocationContext>>();

    public void set(CdiQueryInvocationContext context)
    {
        if (contextStack.get() == null)
        {
            contextStack.set(new Stack<CdiQueryInvocationContext>());
        }
        contextStack.get().push(context);
    }

    @Produces
    public CdiQueryInvocationContext get()
    {
        if (contextStack.get() != null && !contextStack.get().isEmpty())
        {
            return contextStack.get().peek();
        }
        return null;
    }

    public void dispose()
    {
        if (contextStack.get() != null && !contextStack.get().isEmpty())
        {
            CdiQueryInvocationContext ctx = contextStack.get().pop();
            ctx.cleanup();
        }
        if (contextStack.get() != null && contextStack.get().isEmpty())
        {
            contextStack.remove();
        }
    }

}
